@@ -20,14 +20,11 @@ from .jwt_validator import JWTValidator, create_clerk_validator
 from ..models.config import ClientConfig
 
 
-class ClerkConfig(BaseModel):
-    """Clerk configuration."""
+class PlatformAuthConfig(BaseModel):
+    """Platform authentication configuration."""
 
-    client_id: str
-    client_secret: str
-    domain: str
+    api_url: str
     redirect_uri: str = "http://localhost:8080/callback"
-    scope: list[str] = ["openid", "email", "profile"]
 
 
 # ClientConfig is imported from models.config
@@ -42,15 +39,13 @@ class AuthManager:
 
     def __init__(self) -> None:
         self.CONFIG_DIR.mkdir(exist_ok=True)
-        self._load_clerk_config()
+        self._load_platform_config()
         self._jwt_validator: JWTValidator | None = None
 
-    def _load_clerk_config(self) -> None:
-        """Load Clerk configuration from environment or config."""
-        self.clerk_config = ClerkConfig(
-            client_id=os.environ.get("CLERK_CLIENT_ID", ""),
-            client_secret=os.environ.get("CLERK_CLIENT_SECRET", ""),
-            domain=os.environ.get("CLERK_DOMAIN", "https://clerk.dev"),
+    def _load_platform_config(self) -> None:
+        """Load platform configuration from environment or config."""
+        self.platform_config = PlatformAuthConfig(
+            api_url=os.environ.get("VIGIL_API_URL", "http://localhost:3002"),
         )
 
     def _start_callback_server(self, port: int = 8080) -> tuple[str, threading.Thread]:
@@ -181,20 +176,19 @@ Content-Type: text/html
         if not base_url:
             base_url = os.environ.get("VIGIL_API_URL", "https://api.cofactor.app")
 
-        # Decode token to get user info
+        # Get user info from platform using token
         try:
-            # Try to verify signature first
-            try:
-                if not self._jwt_validator:
-                    self._jwt_validator = create_clerk_validator(self.clerk_config.domain)
-                user_info = self._jwt_validator.verify_token(token)
-            except Exception:
-                # Fallback to unverified decoding for development
-                user_info = jwt.decode(token or "", options={"verify_signature": False})
+            import requests
+            user_response = requests.get(
+                f"{base_url}/auth/me",
+                headers={'Authorization': f'Bearer {token}'}
+            )
+            user_response.raise_for_status()
+            user_info = user_response.json()
 
-            # Extract user and organization from token (following AUTH.md spec)
-            username = user_info.get('preferred_username') or user_info.get('email', '').split('@')[0]
-            organization = user_info.get('org_id') or user_info.get('organization', '')
+            # Extract user and organization from platform response
+            username = user_info.get('username') or user_info.get('email', '').split('@')[0]
+            organization = user_info.get('organization_id') or user_info.get('organization', '')
 
             from ..models.config import AuthConfig, PlatformConfig
             config = ClientConfig(
@@ -214,28 +208,24 @@ Content-Type: text/html
             raise
 
     def login_interactive(self, base_url: str | None = None) -> None:
-        """Interactive login via Clerk OAuth with improved UX."""
+        """Interactive login via platform OAuth with improved UX."""
         if not base_url:
             base_url = os.environ.get("VIGIL_API_URL", "https://api.cofactor.app")
 
-        if not self.clerk_config.client_id:
-            raise ValueError("CLERK_CLIENT_ID environment variable not set")
+        # Platform handles OAuth configuration - no client credentials needed
 
-        # Use Clerk's development-friendly redirect URI
+        # Use platform's redirect URI
         redirect_uri = "http://localhost:8080/callback"
 
-        # Create OAuth2 session
-        oauth = OAuth2Session(
-            client_id=self.clerk_config.client_id,
-            redirect_uri=redirect_uri,
-            scope=self.clerk_config.scope
-        )
-
-        # Generate authorization URL
-        auth_url, state = oauth.authorization_url(
-            f"{self.clerk_config.domain}/oauth/authorize",
-            state="vigil-cli-auth"
-        )
+        # Get authorization URL from platform
+        import requests
+        auth_response = requests.get(f"{base_url}/auth/login", params={
+            "redirect_uri": redirect_uri,
+            "client": "vigil-cli"
+        })
+        auth_response.raise_for_status()
+        auth_data = auth_response.json()
+        auth_url = auth_data["auth_url"]
 
         # Improved UI with better formatting
         print("\n🔐 Vigil Platform Authentication")
@@ -317,20 +307,16 @@ Content-Type: text/html
             if not auth_code:
                 raise ValueError("No authorization code found in callback URL")
 
-            # Make direct token request
+            # Exchange code for token via platform
             import requests
             token_data = {
-                'grant_type': 'authorization_code',
                 'code': auth_code,
                 'redirect_uri': redirect_uri,
-                'client_id': self.clerk_config.client_id,
-                'client_secret': self.clerk_config.client_secret,
             }
 
             response = requests.post(
-                f"{self.clerk_config.domain}/oauth/token",
-                data=token_data,
-                headers={'Content-Type': 'application/x-www-form-urlencoded'}
+                f"{base_url}/auth/callback",
+                json=token_data
             )
             response.raise_for_status()
             token_response = response.json()
@@ -342,18 +328,18 @@ Content-Type: text/html
             if access_token:
                 show_spinner("Fetching user information", 0.3)
 
-                # Get user info from Clerk OAuth userinfo endpoint
+                # Get user info from platform
                 try:
                     user_response = requests.get(
-                        f"{self.clerk_config.domain}/oauth/userinfo",
+                        f"{base_url}/auth/me",
                         headers={'Authorization': f'Bearer {access_token}'}
                     )
                     user_response.raise_for_status()
                     user_info = user_response.json()
 
-                    # Extract user and organization from Clerk user info
-                    username = user_info.get('preferred_username') or user_info.get('email', '').split('@')[0]
-                    organization = user_info.get('org_id') or user_info.get('organization', '')
+                    # Extract user and organization from platform user info
+                    username = user_info.get('username') or user_info.get('email', '').split('@')[0]
+                    organization = user_info.get('organization_id') or user_info.get('organization', '')
 
                     print("✅ User information retrieved")
 
@@ -394,7 +380,7 @@ Content-Type: text/html
             print(f"\n❌ Authentication failed: {e}")
             print("\n🔧 Troubleshooting tips:")
             print("   • Check your internet connection")
-            print("   • Verify Clerk OAuth application settings")
+            print("   • Verify platform is running and accessible")
             print("   • Ensure redirect URI matches: http://localhost:8080/callback")
             print("   • Try running: vigil logout (to clear any cached credentials)")
             raise
